let content = {css|@charset "UTF-8";
/* Copyright (c) 2016 The odoc contributors. All rights reserved.
   Distributed under the ISC license, see terms at the end of the file.
   odoc 2.1.0 */

/* Fonts */
@import url('https://fonts.googleapis.com/css?family=Fira+Mono:400,500');
@import url('https://fonts.googleapis.com/css?family=Noticia+Text:400,400i,700');
@import url('https://fonts.googleapis.com/css?family=Fira+Sans:400,400i,500,500i,600,600i,700,700i');

:root,
.light:root {
   --main-background: #FFFFFF;

  --color: #333333;
  --link-color: #2C94BD;
  --anchor-hover: #555;
  --anchor-color: #d5d5d5;
  --xref-shadow: #cc6666;
  --header-shadow: #ddd;
  --by-name-version-color: #aaa;
  --by-name-nav-link-color: #222;
  --target-background: rgba(187, 239, 253, 0.3);
  --target-shadow: rgba(187, 239, 253, 0.8);
  --pre-border-color: #eee;
  --code-background: #f6f8fa;

  --li-code-background: #f6f8fa;
  --li-code-color: #0d2b3e;
  --toc-color: #1F2D3D;
  --toc-before-color: #777;
  --toc-background: #f6f8fa;
  --toc-list-border: #ccc;

  --spec-summary-border-color: #5c9cf5;
  --spec-summary-background: var(--code-background);
  --spec-summary-hover-background: #ebeff2;
  --spec-details-after-background: rgba(0, 4, 15, 0.05);
  --spec-details-after-shadow: rgba(204, 204, 204, 0.53);
}

.dark:root {
  --main-background: #202020;
  --code-background: #222;
  --line-numbers-background: rgba(0, 0, 0, 0.125);
  --navbar-background: #202020;

  --color: #bebebe;
  --dirname-color: #666;
  --underline-color: #444;
  --visited-color: #002800;
  --visited-number-color: #252;
  --unvisited-color: #380000;
  --unvisited-number-color: #622;
  --somevisited-color: #303000;
  --highlight-color: #303e3f;
  --line-number-color: rgba(230, 230, 230, 0.3);
  --unvisited-margin-color: #622;
  --border: #333;
  --navbar-border: #333;
  --code-color: #ccc;

  --li-code-background: #373737;
  --li-code-color: #999;
  --toc-color: #777;
  --toc-background: #252525;

  --hljs-link: #999;
  --hljs-keyword: #cda869;
  --hljs-regexp: #f9ee98;
  --hljs-title: #dcdcaa;
  --hljs-type: #ac885b;
  --hljs-meta: #82aaff;
  --hljs-variable: #cf6a4c;
}

@media (prefers-color-scheme: dark) {
  :root {
    --main-background: #202020;
    --code-background: #333;
    --line-numbers-background: rgba(0, 0, 0, 0.125);
    --navbar-background: #202020;

    --meter-unvisited-color: #622;
    --meter-visited-color: #252;
    --meter-separator-color: black;

    --color: #bebebe;
    --dirname-color: #666;
    --underline-color: #444;
    --visited-color: #002800;
    --visited-number-color: #252;
    --unvisited-color: #380000;
    --unvisited-number-color: #622;
    --somevisited-color: #303000;
    --highlight-color: #303e3f;
    --line-number-color: rgba(230, 230, 230, 0.3);
    --unvisited-margin-color: #622;
    --border: #333;
    --navbar-border: #333;
    --code-color: #ccc;
    --by-name-nav-link-color: var(--color);

    --li-code-background: #373737;
    --li-code-color: #999;
    --toc-color: #777;
    --toc-before-color: #777;
    --toc-background: #252525;
    --toc-list-border: #ccc;
    --spec-summary-hover-background: #ebeff2;
    --spec-details-after-background: rgba(0, 4, 15, 0.05);
    --spec-details-after-shadow: rgba(204, 204, 204, 0.53);

    --hljs-link: #999;
    --hljs-keyword: #cda869;
    --hljs-regexp: #f9ee98;
    --hljs-title: #dcdcaa;
    --hljs-type: #ac885b;
    --hljs-meta: #82aaff;
    --hljs-variable: #cf6a4c;
  }
}

/* Reset a few things. */

html, body, div, span, applet, object, iframe, h1, h2, h3, h4, h5, h6, p, blockquote, pre, a, abbr, acronym, address, big, cite, code, del, dfn, em, img, ins, kbd, q, s, samp, small, strike, strong, sub, sup, tt, var, b, u, i, center, dl, dt, dd, ol, ul, li, fieldset, form, label, legend, table, caption, tbody, tfoot, thead, tr, th, td, article, aside, canvas, details, embed, figure, figcaption, footer, header, hgroup, menu, nav, output, ruby, section, summary, time, mark, audio, video {
  padding: 0;
  border: 0;
  font: inherit;
  vertical-align: baseline;

}

table {
  border-collapse: collapse;
  border-spacing: 0;
}

*, *:before, *:after {
  box-sizing: border-box;
}

html {
  font-size: 15px;
}

body {
  text-align: left;
  background: #FFFFFF;
  color: var(--color);
  background-color: var(--main-background);
}

body {
  max-width: 100ex;
  margin-left: calc(10vw + 20ex);
  margin-right: 4ex;
  margin-top: 20px;
  margin-bottom: 50px;
  font-family: "Noticia Text", Georgia, serif;
  line-height: 1.5;
}

header {
  margin-bottom: 30px;
}

nav {
  font-family: "Fira Sans", Helvetica, Arial, sans-serif;
}

/* Basic markup elements */

b, strong {
  font-weight: bold;
}

i {
  font-style: italic;
}

em, i em.odd{
  font-style: italic;
}

em.odd, i em {
  font-style: normal;
}

sup {
  vertical-align: super;
}

sub {
  vertical-align: sub;
}

sup, sub {
  font-size: 12px;
  line-height: 0;
  margin-left: 0.2ex;
}

ul, ol {
  list-style-position: outside
}

ul>li {
  margin-left: 22px;
}

ol>li {
  margin-left: 27.2px;
}

li>*:first-child {
  margin-top: 0
}

/* Text alignements, this should be forbidden. */

.left {
  text-align: left;
}

.right {
  text-align: right;
}

.center {
  text-align: center;
}

/* Links and anchors */

a {
  text-decoration: none;
  color: var(--link-color);
}

a:hover {
  box-shadow: 0 1px 0 0 var(--link-color);
}

/* Linked highlight */
*:target {
  background-color: var(--target-background) !important;
  box-shadow: 0 0px 0 1px var(--target-shadow) !important;
  border-radius: 1px;
}

*:hover > a.anchor {
  visibility: visible;
}

a.anchor:before {
  content: "#";
}

a.anchor:hover {
  box-shadow: none;
  text-decoration: none;
  color: var(--anchor-hover);
}

a.anchor {
  visibility: hidden;
  position: absolute;
  /* top: 0px; */
  /* margin-left: -3ex; */
  margin-left: -1.3em;
  font-weight: normal;
  font-style: normal;
  padding-right: 0.4em;
  padding-left: 0.4em;
  /* To remain selectable */
  color: var(--anchor-color);
}

.spec > a.anchor {
  margin-left: -2.3em;
  padding-right: 0.9em;
}

.xref-unresolved {
  color: #2C94BD;
}
.xref-unresolved:hover {
  box-shadow: 0 1px 0 0 var(--xref-shadow);
}

/* Section and document divisions.
   Until at least 4.03 many of the modules of the stdlib start at .h7,
   we restart the sequence there like h2  */

h1, h2, h3, h4, h5, h6, .h7, .h8, .h9, .h10 {
  font-family: "Fira Sans", Helvetica, Arial, sans-serif;
  font-weight: 400;
  padding-top: 0.1em;
  line-height: 1.2;
  overflow-wrap: break-word;
}

h1 {
  font-weight: 500;
  font-size: 2.441em;
}

h1 {
  font-weight: 500;
  font-size: 1.953em;
  box-shadow: 0 1px 0 0 var(--header-shadow);
}

h2 {
  font-size: 1.563em;
}

h3 {
  font-size: 1.25em;
}

small, .font_small {
  font-size: 0.8em;
}

h1 code, h1 tt {
  font-size: inherit;
  font-weight: inherit;
}

h2 code, h2 tt {
  font-size: inherit;
  font-weight: inherit;
}

h3 code, h3 tt {
  font-size: inherit;
  font-weight: inherit;
}

h3 code, h3 tt {
  font-size: inherit;
  font-weight: inherit;
}

h4 {
  font-size: 1.12em;
}

/* Comment delimiters, hidden but accessible to screen readers and 
   selected for copy/pasting */

/* Taken from bootstrap */
/* See also https://stackoverflow.com/a/27769435/4220738 */
.comment-delim {
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  white-space: nowrap;
  border: 0;
}

/* Preformatted and code */

tt, code, pre {
  font-family: "Fira Mono", courier;
  font-weight: 400;
}

pre {
  padding: 0.1em;
  border: 1px solid var(--pre-border-color);
  border-radius: 5px;
  overflow-x: auto;
}

p code,
li code {
  background-color: var(--li-code-background);
  color: var(--li-code-color);
  border-radius: 3px;
  padding: 0 0.3ex;
}

p a > code {
  color: var(--link-color);
}

code {
  white-space: pre-wrap;
}

/* Code blocks (e.g. Examples) */

pre code {
  font-size: 0.893rem;
}

/* Code lexemes */

.keyword {
  font-weight: 500;
}

.arrow { white-space: nowrap }

/* Module member specification */

.spec {
  background-color: var(--spec-summary-background);
  border-radius: 3px;
  border-left: 4px solid var(--spec-summary-border-color);
  border-right: 5px solid transparent;
  padding: 0.35em 0.5em;
}

.def-doc {
  margin-bottom: 10px;
}

/* Spacing between items */
div.odoc-spec,.odoc-include {
  margin-bottom: 2em;
}

.spec.type .variant {
  margin-left: 2ch;
}
.spec.type .variant p {
  margin: 0;
  font-style: italic;
}
.spec.type .record {
  margin-left: 2ch;
}
.spec.type .record p {
  margin: 0;
  font-style: italic;
}

div.def {
  margin-top: 0;
  text-indent: -2ex;
  padding-left: 2ex;
}

div.def+div.def-doc {
  margin-left: 1ex;
  margin-top: 2.5px
}

div.def-doc>*:first-child {
  margin-top: 0;
}

/* Collapsible inlined include and module */

.odoc-include details {
  position: relative;
}

.odoc-include.shadowed-include {
  display: none;
}

.odoc-include details:after {
  z-index: -100;
  display: block;
  content: " ";
  position: absolute;
  border-radius: 0 1ex 1ex 0;
  right: -20px;
  top: 1px;
  bottom: 1px;
  width: 15px;
  background: var(--spec-details-after-background, rgba(0, 4, 15, 0.05));
  box-shadow: 0 0px 0 1px var(--spec-details-after-shadow, rgba(204, 204, 204, 0.53));
}

.odoc-include summary {
  position: relative;
  margin-bottom: 1em;
  cursor: pointer;
  outline: none;
}

.odoc-include summary:hover {
  background-color: var(--spec-summary-hover-background);
}

/* FIXME: Does not work in Firefox. */
.odoc-include summary::-webkit-details-marker {
  color: #888;
  transform: scaleX(-1);
  position: absolute;
  top: calc(50% - 5px);
  height: 11px;
  right: -29px;
}

/* Records and variants FIXME */

div.def table {
  text-indent: 0em;
  padding: 0;
  margin-left: -2ex;
}

td.def {
  padding-left: 2ex;
}

td.def-doc *:first-child {
  margin-top: 0em;
}

/* Lists of @tags */

.at-tags { list-style-type: none; margin-left: -3ex; }
.at-tags li { padding-left: 3ex; text-indent: -3ex; }
.at-tags .at-tag { text-transform: capitalize }

/* Lists of modules */

.modules { list-style-type: none; margin-left: -3ex; }
.modules li { padding-left: 3ex; text-indent: -3ex; margin-top: 5px }
.modules .synopsis { padding-left: 1ch; }

/* Odig package index */

.packages { list-style-type: none; margin-left: -3ex; }
.packages li { padding-left: 3ex; text-indent: -3ex }
.packages li a.anchor { padding-right: 0.5ch; padding-left: 3ch; }
.packages .version { font-size: 10px; color: var(--by-name-version-color); }
.packages .synopsis { padding-left: 1ch }

.by-name nav a {
  text-transform: uppercase;
  font-size: 18px;
  margin-right: 1ex;
  color: var(--by-name-nav-link-color,);
  display: inline-block;
}

.by-tag nav a {
  margin-right: 1ex;
  color: var(--by-name-nav-link-color);
  display: inline-block;
}

.by-tag ol { list-style-type: none; }
.by-tag ol.tags li { margin-left: 1ch; display: inline-block }
.by-tag td:first-child { text-transform: uppercase; }

/* Odig package page */

.package nav {
  display: inline;
  font-size: 14px;
  font-weight: normal;
}

.package .version {
  font-size: 14px;
}

.package.info {
  margin: 0;
}

.package.info td:first-child {
  font-style: italic;
  padding-right: 2ex;
}

.package.info ul {
  list-style-type: none;
  display: inline;
  margin: 0;
}

.package.info li {
  display: inline-block;
  margin: 0;
  margin-right: 1ex;
}

#info-authors li, #info-maintainers li {
  display: block;
}

/* Sidebar and TOC */

.odoc-toc:before {
  display: block;
  content: "Contents";
  text-transform: uppercase;
  font-size: 1em;
  margin: 1.414em 0 0.5em;
  font-weight: 500;
  color: var(--toc-before-color);
  line-height: 1.2;
}

.odoc-toc {
  position: fixed;
  top: 0px;
  bottom: 0px;
  left: 0px;
  max-width: 30ex;
  min-width: 26ex;
  width: 20%;
  background: var(--toc-background);
  overflow: auto;
  color: var(--toc-color);
  padding-left: 2ex;
  padding-right: 2ex;
}

.odoc-toc ul li a {
  font-family: "Fira Sans", sans-serif;
  font-size: 0.95em;
  color: var(--color);
  font-weight: 400;
  line-height: 1.6em;
  display: block;
}

.odoc-toc ul li a:hover {
  box-shadow: none;
  text-decoration: underline;
}

/* First level titles */

.odoc-toc>ul>li>a {
  font-weight: 500;
}

.odoc-toc li ul {
  margin: 0px;
}

.odoc-toc ul {
  list-style-type: none;
}

.odoc-toc ul li {
  margin: 0;
}
.odoc-toc>ul>li {
  margin-bottom: 0.3em;
}

.odoc-toc ul li li {
  border-left: 1px solid var(--toc-list-border);
  margin-left: 5px;
  padding-left: 12px;
}

/* Mobile adjustements. */

@media only screen and (max-width: 95ex) {
  .odoc-content {
    margin: auto;
    padding: 2em;
  }
  .odoc-toc {
    position: static;
    width: auto;
    min-width: unset;
    max-width: unset;
    border: none;
    padding: 0.2em 1em;
    border-radius: 5px;
  }
}

/* Print adjustements. */

@media print {
  body {
    color: black;
    background: white;
  }
  body nav:first-child {
    visibility: hidden;
  }
}

/* Syntax highlighting (based on github-gist) */

.hljs {
  display: block;
  background: var(--code-background);
  padding: 0.5em;
  color: var(--color);
  overflow-x: auto;
}

.hljs-comment,
.hljs-meta {
  color: #969896;
}

.hljs-string,
.hljs-variable,
.hljs-template-variable,
.hljs-strong,
.hljs-emphasis,
.hljs-quote {
  color: #df5000;
}

.hljs-keyword,
.hljs-selector-tag {
  color: #a71d5d;
}

.hljs-type,
.hljs-class .hljs-title {
  color: #458;
  font-weight: 500;
}

.hljs-literal,
.hljs-symbol,
.hljs-bullet,
.hljs-attribute {
  color: #0086b3;
}

.hljs-section,
.hljs-name {
  color: #63a35c;
}

.hljs-tag {
  color: #333333;
}

.hljs-attr,
.hljs-selector-id,
.hljs-selector-class,
.hljs-selector-attr,
.hljs-selector-pseudo {
  color: #795da3;
}

.hljs-addition {
  color: #55a532;
  background-color: #eaffea;
}

.hljs-deletion {
  color: #bd2c00;
  background-color: #ffecec;
}

.hljs-link {
  text-decoration: underline;
}

/*---------------------------------------------------------------------------
   Copyright (c) 2016 The odoc contributors

   Permission to use, copy, modify, and/or distribute this software for any
   purpose with or without fee is hereby granted, provided that the above
   copyright notice and this permission notice appear in all copies.

   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
   WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
   MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
   ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
   WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
   ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  ---------------------------------------------------------------------------*/
|css}